Effects

Struct Effects 

pub struct Effects { /* private fields */ }
Complete instruction effects. must_* is always a subset of may_*.

Implementations

Source

impl Effects

pub const fn must_read(&self) -> &ResourceSet

Resources read in every interpretation allowed by the context.

pub const fn may_read(&self) -> &ResourceSet

Resources that may be read in at least one allowed interpretation.

pub const fn must_write(&self) -> &ResourceSet

Resources written in every interpretation allowed by the context.

pub const fn may_write(&self) -> &ResourceSet

Resources that may be written in at least one allowed interpretation.

pub fn memory(&self) -> impl Iterator<Item = MemoryAccess> + '_

Memory accesses in architectural order.

pub const fn control_flow(&self) -> ControlFlow

Control-flow classification.