pub struct Effects { /* private fields */ }Expand description
Complete instruction effects. must_* is always a subset of may_*.
Implementations
Sourceimpl Effects
impl Effects
Sourcepub const fn must_read(&self) -> &ResourceSet
pub const fn must_read(&self) -> &ResourceSet
Resources read in every interpretation allowed by the context.
Sourcepub const fn may_read(&self) -> &ResourceSet
pub const fn may_read(&self) -> &ResourceSet
Resources that may be read in at least one allowed interpretation.
Sourcepub const fn must_write(&self) -> &ResourceSet
pub const fn must_write(&self) -> &ResourceSet
Resources written in every interpretation allowed by the context.
Sourcepub const fn may_write(&self) -> &ResourceSet
pub const fn may_write(&self) -> &ResourceSet
Resources that may be written in at least one allowed interpretation.
Sourcepub fn memory(&self) -> impl Iterator<Item = MemoryAccess> + '_
pub fn memory(&self) -> impl Iterator<Item = MemoryAccess> + '_
Memory accesses in architectural order.
Sourcepub const fn control_flow(&self) -> ControlFlow
pub const fn control_flow(&self) -> ControlFlow
Control-flow classification.